#
# spec file for package python-cytoolz
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-cytoolz
Version:        1.0.1
Release:        1.1
Summary:        High performance python functional utilities in Cython
License:        BSD-3-Clause
URL:            https://github.com/pytoolz/cytoolz
Source:         https://files.pythonhosted.org/packages/source/c/cytoolz/cytoolz-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-toolz
%python_subpackages

%description
Cython implementation of the toolz package, which provides high
performance utility functions for iterables, functions, and
dictionaries.

%prep
%setup -q -n cytoolz-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -r %{buildroot}%{$python_sitearch}/cytoolz/tests
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/cytoolz/
%{python_sitearch}/cytoolz-%{version}*-info/

%changelog
* Thu Jan 23 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.0.1
  * Add support for Python 3.13
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
* Thu Oct 10 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Test fixes for Python 3.13
  * Drop Python 3.7
  * Bump ``cibuildwheel`` in CI
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.12.3:
  * Add support for Python 3.12, PyPy 3.9, and PyPy 3.10
  * Update to match `toolz` 0.12.1
* Wed Jul 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.2:
  * Support Cython 3.0 (#199)
  * Stop building wheels for PyPy 3.9 and PyPy 3.10, which
    stopped working for some reason (#199)
* Wed Mar  1 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.12.1
  * Support Python 3.11 (including wheels)
  * Drop Python 3.5 support
- 0.12.0
  * Update to toolz 0.12.0 (#170)
  * See toolz release notes:
    https://github.com/pytoolz/toolz/releases/tag/0.12.0
  * Build wheels automatically with cibuildwheel! (#167, #168, #169, #170)
  * Support newer Python versions (#165, don't use inspect.getargspec
    in tests)
  * Improve import times
  * Use versioneer.py to manage versions
  * __version__ and __toolz_version__ are no longer available from
    cytoolz._version--use cython.__toolz_version__ instead.
* Mon Jan 10 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.11.2
  * Support Python 3.10
- No further release notes found
  * Dropped support for Python <= 3.4
  * Officially uses pytest now
* Mon Mar 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Use pytest instead of nose
* Fri Nov  8 2019 marec@detebe.org
- version update to 0.10.1
* Wed Jul 24 2019 pgajdos@suse.com
- version update to 0.10.0
  * no upstream change log found
- turn on testsuite
* Thu May  3 2018 toddrme2178@gmail.com
- Update to version 0.9.0.1
  * do not worry abount having good introspection on breakpoint
  * Backport fix to a test from cytoolz.
  * A slightly faster interposed.
  * Don't import or reference `toolz.curried.exceptions`.
* Tue Jan 30 2018 guigo.lourenco@hotmail.com
- Add missing requires.
* Sat Apr 15 2017 toddrme2178@gmail.com
- Update to 0.8.2
  * No upstream changelog
- Implement single-spec version
* Mon Aug 31 2015 toddrme2178@gmail.com
- update to version 0.7.3 (taken from git log):
  * Add factory keyword functionality to dicttoolz.
  * Add diff and prepare for "factory" keyword argument in dictoolz.
  * Merge pull request #64 from eriknw/fix/pluck_memleak
  * Fix memory leak in curry.
  * This is one way to fix the memory leak in #63.
  * Merge pull request #59 from eriknw/topk
  * Merge pull request #58 from eriknw/stricter_dev_tests
  * Add topk.
  * Don't require nose to run tests (including dev tests).
  * Make running dev tests comparing toolz to cytoolz more strict.
* Wed May 20 2015 toddrme2178@gmail.com
- specfile:
  * added toolz requirement
    (only needed for testing, which is currently not enabled)
- update to version 0.7.2 (taken from git log):
  * ship tests with code
  * clean up build
  * relative import
  * Use absolute imports in pyx files to support Cython 0.17 and later.
  * Fix merge_sorted with key function (see #55).
  * better support for 3.4
* Tue Mar  3 2015 toddrme2178@gmail.com
- Update to 0.7.1
  * Test `nth` with negative index on sequence and iterator.
  * Add itemmap, itemfilter to api doc.
  * Add `itemmap` and `itemfilter` to `dicttoolz`.
  * binstar: add more platforms/versions
  * add tail to itertoolz.__all__
  * take, drop, tail refer to each other in docstrings
  * test tail in lazy setting
  * fix tail doctest
  * last is a recipe of tail
  * add tail operation
  * pep8 space error fix
  * Identity doc string
  * add dissoc function to dictoolz
  * Describe the ideal contribution
  * reduceby takes callable init keyword argument
  * Add pypy3 to build matrix
  * getter works in empty index case
  * simpler check on index in get
  * get([], seq) returns ()
* Thu Sep 11 2014 toddrme2178@gmail.com
- Update to 0.7.0
  * No upstream changelog
* Fri May 30 2014 toddrme2178@gmail.com
- initial version
